PDG Python API
==============

The Python package `pdg` provides programmatic access to the data
published by the  Particle Data Group (PDG) in the *Review of Particle Physics*.
The *Review of Particle Physics* is available online from the PDG website at https://pdg.lbl.gov.
General information about PDG and the *Review of Particle Physics*
can be found at https://pdg.lbl.gov/about.

Documentation is available at https://pdgapi.lbl.gov/doc.

The source code for this package can be found at https://github.com/particledatagroup/api.
This repository uses Git LFS to manage SQlite database files. You need to have Git LFS installed
before checking out the repository with git. Please see the instructions at https://github.com/git-lfs/git-lfs.

To provide feedback or report bugs, please [submit an Issue](https://github.com/particledatagroup/api/issues)
or contact [api@pdg.lbl.gov](mailto:api@pdg.lbl.gov).
